@@ -28,20 +28,29 @@
 
 __all__ = (
     "API_BASE_URL",
+    "API_GROUPS_URL",
+    "API_GROUP_ITEMS_URL",
+    "API_REPORTS_URL",
     "API_SCOPES",
-    "Analytics",
-    "AsyncAnalytics",
+    "AsyncBaseClient",
+    "AsyncClient",
     "can_use",
+    "Client",
+    "enable_logging",
+    "groups",
     "OAUTH_CHECK_URL",
-    "setup_logging",
+    "reports",
+    "requires",
     "UPDATE_CHECK_URL",
+    "warn",
+    "warn_on_call",
 )
 
 __productname__ = "analytix"
-__version__ = "3.6.1"
+__version__ = "4.0.0"
 __description__ = "A simple yet powerful wrapper for the YouTube Analytics API."
 __url__ = "https://github.com/parafoxia/analytix"
-__docs__ = "https://analytix.readthedocs.io"
+__docs__ = "https://parafoxia.github.io/analytix/"
 __author__ = "Ethan Henderson"
 __author_email__ = "ethan.henderson.1998@gmail.com"
 __license__ = "BSD 3-Clause 'New' or 'Revised' License"
@@ -49,25 +58,10 @@ __bugtracker__ = "https://github.com/parafoxia/analytix/issues"
 __ci__ = "https://github.com/parafoxia/analytix/actions"
 __changelog__ = "https://github.com/parafoxia/analytix/releases"
 
-from pkg_resources import working_set
-
-
-def can_use(package: str) -> bool:
-    """Whether a given package is available, and can be used by
-    analytix.
-
-    Args:
-        package:
-            The package to check against.
-
-    Returns:
-        Whether the given package can be used.
-    """
-
-    return package in [p.key for p in working_set]
-
-
-API_BASE_URL = "https://youtubeanalytics.googleapis.com/v2/reports?"
+API_BASE_URL = "https://youtubeanalytics.googleapis.com/v2/"
+API_REPORTS_URL = API_BASE_URL + "reports?"
+API_GROUPS_URL = API_BASE_URL + "groups?"
+API_GROUP_ITEMS_URL = API_BASE_URL + "groupItems?"
 API_SCOPES = (
     "https://www.googleapis.com/auth/yt-analytics.readonly",
     "https://www.googleapis.com/auth/yt-analytics-monetary.readonly",
@@ -75,6 +69,7 @@ API_SCOPES = (
 OAUTH_CHECK_URL = "https://www.googleapis.com/oauth2/v3/tokeninfo?access_token="
 UPDATE_CHECK_URL = "https://pypi.org/pypi/analytix/json"
 
-from .analytics import Analytics
-from .async_analytics import AsyncAnalytics
-from .ux import setup_logging
+from . import groups, reports
+from .client import AsyncBaseClient, AsyncClient, Client
+from .utils import *
+from .ux import enable_logging
