@@ -26,18 +26,19 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+"""User experience utilities for analytix."""
+
 from __future__ import annotations
 
+__all__ = ("display_splash", "enable_logging")
+
 import logging
 import platform
 import typing as t
-import warnings
 from importlib.util import find_spec
 
 import analytix
 
-_log = logging.getLogger(__name__)
-
 BANNER = r"""
 {r}            {o}             {y}            {g}88  {b}             {i}         {v}88
 {r}            {o}             {y}            {g}88  {b}             {i}  ,d     {v}""
@@ -90,18 +91,26 @@ def display_splash() -> None:
     )
 
 
-def setup_logging(level: int = logging.INFO) -> logging.StreamHandler[t.TextIO]:
+def enable_logging(level: int = logging.INFO) -> logging.StreamHandler[t.TextIO]:
     """Enable analytix's preconfigured logger.
 
-    Args:
-        level:
-            The log level to use. Defaults to INFO.
+    Parameters
+    ----------
+    level : int
+        The log level to use.
 
-    Returns:
+    Returns
+    -------
+    StreamHandler object
         The created log handler.
+
+    ??? example
+        ```py
+        analytix.enable_logging(logging.DEBUG)
+        ```
     """
 
-    FMT = "{relativeCreated:>05.0f} [{levelname:^9}] {name}: {message}"
+    FMT = "{relativeCreated:>7,.0f}ms [ {levelname:<7} ] {name}: {message}"
     FORMATS = {
         logging.DEBUG: f"\33[38;5;244m{FMT}\33[0m",
         logging.INFO: f"\33[38;5;248m{FMT}\33[0m",
@@ -123,10 +132,3 @@ def setup_logging(level: int = logging.INFO) -> logging.StreamHandler[t.TextIO]:
         handlers=[handler],
     )
     return handler
-
-
-def _warn(message: str) -> None:
-    if _log.hasHandlers() and _log.getEffectiveLevel() <= 30:
-        _log.warning(message)
-    else:
-        warnings.warn(message)
